componenttools.number_is_between_prolated_start_and_stop_offsets_of_component
=============================================================================

.. autofunction:: abjad.tools.componenttools.number_is_between_prolated_start_and_stop_offsets_of_component.number_is_between_prolated_start_and_stop_offsets_of_component
